@@ -13,13 +13,17 @@ def _get_matched_action(content_encoding_name):
         return content_encoding_handlers[content_encoding_name]
     return DefaultHandler
 
-def origin2flow(content_encoding, request_data):
+def origin2flow(content_encoding, request_data, chain=None):
     func = _get_matched_action(content_encoding)
     try:
         _data = func.origin2flow(request_data)
     except Exception as e:
-        _data = DefaultHandler.origin2flow(request_data)
+        func = DefaultHandler
+        _data = func.origin2flow(request_data)
         logger.warning(f'Convert Content-Encoding: {content_encoding} data origin2flow failed! {e}')
+    finally:
+        chain.append(func)
+
     return _data
 
 def flow2origin(content_encoding, flow_data):
